Coverage for scipy\special\sf_error.py: 0%

# Coverage for scipy\special\sf_error.py : 0%

## 6 statements 0 run 6 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | """Warnings and Exceptions that can be raised by special functions.""" import warnings class SpecialFunctionWarning(Warning): """Warning that can be emitted by special functions.""" pass warnings.simplefilter("always", category=SpecialFunctionWarning) class SpecialFunctionError(Exception): """Exception that can be raised by special functions.""" pass